# apfio-imaging #

This package extends [apfio](https://pypi.org/project/apfio/) by support for many image compression algorithms (via [pillow](https://pypi.org/project/pillow/)), including AVIF (via [PyAV](https://pypi.org/project/av/)).
